==> ultracopier-src-2.2.6.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/fr/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="+341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Achetez la version Ultimate pour financer le développement</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Register your key</source>
        <translation>Enregistrez votre clé</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Fichier %1/%2, taille: %3/%4</translation>
    </message>
    <message>
        <location line="+234"/>
        <source>Copy list</source>
        <translation>Liste de copies</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move list</source>
        <translation>Liste de déplacements</translation>
    </message>
    <message>
        <location line="+441"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Garder ouvert s&apos;il y a des erreurs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Never close</source>
        <translation>Ne jamais fermer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Always close</source>
        <translation>Toujours fermer</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>File Name, 0KB</source>
        <translation>Nom de fichier, 0Ko</translation>
    </message>
    <message>
        <location line="+275"/>
        <location line="+12"/>
        <location line="+12"/>
        <source>Select a color</source>
        <translation>Selectionner une coleur</translation>
    </message>
    <message>
        <location line="+75"/>
        <location line="+4"/>
        <location line="+2"/>
        <source>%1 %2% of %3</source>
        <translation>%1 de %2% de %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="+295"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Garder ouvert s&apos;il y a des erreurs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Never close</source>
        <translation>Ne jamais fermer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Always close</source>
        <translation>Toujours fermer</translation>
    </message>
    <message>
        <location line="+214"/>
        <location line="+15"/>
        <location line="+15"/>
        <source>Select a color</source>
        <translation>Selectionner une coleur</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="+44"/>
        <source>From:</source>
        <translation>Depuis:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>To:</source>
        <translation>Vers:</translation>
    </message>
    <message>
        <location line="+161"/>
        <source>&amp;More</source>
        <translation>Pl&amp;us</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location line="-153"/>
        <source>Close on transfer completion</source>
        <translation>Fermer à la fin des transferts</translation>
    </message>
    <message>
        <location line="+168"/>
        <source>Limit copy speed to:</source>
        <translation>Limiter la vitesse de copie à:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Transfer list</source>
        <translation>Liste de transferts</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Move the selected items to the top</source>
        <translation>Déplacer l&apos;item selectionné au debut</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move up the selected items</source>
        <translation>Déplacer l&apos;item selectionné vers le haut</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move down the selected items</source>
        <translation>Déplacer l&apos;item selectionné vers le bas</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move the selected items to the bottom</source>
        <translation>Déplacer l&apos;item selectionné à la fin</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Add file/folder</source>
        <translation>Ajouter fichier/dossier</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Delete the selected items</source>
        <translation>Supprimer les items sélectionnés</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Export the transfer list</source>
        <translation>Exporter la liste de transfert</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Import the transfer list</source>
        <translation>Importer la liste de transfert</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location line="+35"/>
        <location line="+69"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location line="-49"/>
        <source>Export the errors into transfer list</source>
        <translation>Exporter les erreurs dans une liste de transfert</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Add file</source>
        <translation>Ajouter un fichier</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add folder</source>
        <translation>Ajouter un répertoire</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move file(s)</source>
        <translation>Déplacer le(s) fichier(s)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move folder</source>
        <translation>Déplacer un répertoire</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy file(s)</source>
        <translation>Copier le(s) fichier(s)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy folder</source>
        <translation>Copier un répertoire</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="+402"/>
        <source>Show dual progression</source>
        <translation>Afficher une double progression</translation>
    </message>
    <message>
        <location line="-183"/>
        <source>Show speed as main information</source>
        <translation>Afficher la vitesse comme information principale</translation>
    </message>
    <message>
        <location line="-175"/>
        <source>Use</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <location line="+129"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Déplier automatiquement les détails</translation>
    </message>
    <message>
        <location line="-106"/>
        <source>Minimize on close to systray</source>
        <translation>Minimiser à la fermeture dans le systray</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>At the end of the copy</source>
        <translation>À la fin de la copie</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+34"/>
        <source>Limit copy speed to</source>
        <translation>Limiter la vitesse de copie à</translation>
    </message>
    <message>
        <location line="-84"/>
        <source>Start minimized</source>
        <translation>Démarrer minimisé</translation>
    </message>
    <message>
        <location line="+160"/>
        <source>Information</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Click to edit the color</source>
        <translation>Cliquer pour éditer la couleur</translation>
    </message>
    <message>
        <location line="-122"/>
        <source> KB/s</source>
        <translation> Ko/s</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Save position</source>
        <translation>Sauvegarder la position</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Speed with progress bar</source>
        <translation>Vitesse avec barre de progression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progression color</source>
        <translation>Couleur de progression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show progression in the title</source>
        <translation>Afficher la progression dans le titre</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>General margin</source>
        <translation>Marge générale</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>General spacing</source>
        <translation>Espacement général</translation>
    </message>
    <message>
        <location line="-242"/>
        <source>Always on top</source>
        <translation>Toujours au 1er plan</translation>
    </message>
</context>
</TS>

==> ultracopier-src-3.0.0.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/fr/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="+351"/>
        <location line="+6"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Achetez la version Ultimate pour financer le développement</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Ultimate version have more performance via OS native copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Register your key</source>
        <translation>Enregistrez votre clé</translation>
    </message>
    <message>
        <location line="+100"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Fichier %1/%2, taille: %3/%4</translation>
    </message>
    <message>
        <location line="+234"/>
        <source>Copy list</source>
        <translation>Liste de copies</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move list</source>
        <translation>Liste de déplacements</translation>
    </message>
    <message>
        <location line="+441"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Garder ouvert s&apos;il y a des erreurs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Never close</source>
        <translation>Ne jamais fermer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Always close</source>
        <translation>Toujours fermer</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>File Name, 0KB</source>
        <translation>Nom de fichier, 0Ko</translation>
    </message>
    <message>
        <location line="+275"/>
        <location line="+12"/>
        <location line="+12"/>
        <source>Select a color</source>
        <translation>Selectionner une coleur</translation>
    </message>
    <message>
        <location line="+75"/>
        <location line="+4"/>
        <location line="+2"/>
        <source>%1 %2% of %3</source>
        <translation>%1 de %2% de %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="+295"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Garder ouvert s&apos;il y a des erreurs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Never close</source>
        <translation>Ne jamais fermer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Always close</source>
        <translation>Toujours fermer</translation>
    </message>
    <message>
        <location line="+214"/>
        <location line="+15"/>
        <location line="+15"/>
        <source>Select a color</source>
        <translation>Selectionner une coleur</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="+44"/>
        <source>From:</source>
        <translation>Depuis:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>To:</source>
        <translation>Vers:</translation>
    </message>
    <message>
        <location line="+161"/>
        <source>&amp;More</source>
        <translation>Pl&amp;us</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location line="-153"/>
        <source>Close on transfer completion</source>
        <translation>Fermer à la fin des transferts</translation>
    </message>
    <message>
        <location line="+168"/>
        <source>Limit copy speed to:</source>
        <translation>Limiter la vitesse de copie à:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Transfer list</source>
        <translation>Liste de transferts</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Move the selected items to the top</source>
        <translation>Déplacer l&apos;item selectionné au debut</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move up the selected items</source>
        <translation>Déplacer l&apos;item selectionné vers le haut</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move down the selected items</source>
        <translation>Déplacer l&apos;item selectionné vers le bas</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Move the selected items to the bottom</source>
        <translation>Déplacer l&apos;item selectionné à la fin</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Add file/folder</source>
        <translation>Ajouter fichier/dossier</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Delete the selected items</source>
        <translation>Supprimer les items sélectionnés</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Export the transfer list</source>
        <translation>Exporter la liste de transfert</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Import the transfer list</source>
        <translation>Importer la liste de transfert</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location line="+35"/>
        <location line="+69"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location line="-49"/>
        <source>Export the errors into transfer list</source>
        <translation>Exporter les erreurs dans une liste de transfert</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Add file</source>
        <translation>Ajouter un fichier</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add folder</source>
        <translation>Ajouter un répertoire</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move file(s)</source>
        <translation>Déplacer le(s) fichier(s)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Move folder</source>
        <translation>Déplacer un répertoire</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy file(s)</source>
        <translation>Copier le(s) fichier(s)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy folder</source>
        <translation>Copier un répertoire</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="+402"/>
        <source>Show dual progression</source>
        <translation>Afficher une double progression</translation>
    </message>
    <message>
        <location line="-183"/>
        <source>Show speed as main information</source>
        <translation>Afficher la vitesse comme information principale</translation>
    </message>
    <message>
        <location line="-175"/>
        <source>Use</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <location line="+129"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Déplier automatiquement les détails</translation>
    </message>
    <message>
        <location line="-106"/>
        <source>Minimize on close to systray</source>
        <translation>Minimiser à la fermeture dans le systray</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>At the end of the copy</source>
        <translation>À la fin de la copie</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+34"/>
        <source>Limit copy speed to</source>
        <translation>Limiter la vitesse de copie à</translation>
    </message>
    <message>
        <location line="-84"/>
        <source>Start minimized</source>
        <translation>Démarrer minimisé</translation>
    </message>
    <message>
        <location line="+160"/>
        <source>Information</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Click to edit the color</source>
        <translation>Cliquer pour éditer la couleur</translation>
    </message>
    <message>
        <location line="-122"/>
        <source> KB/s</source>
        <translation> Ko/s</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Save position</source>
        <translation>Sauvegarder la position</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Speed with progress bar</source>
        <translation>Vitesse avec barre de progression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progression color</source>
        <translation>Couleur de progression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show progression in the title</source>
        <translation>Afficher la progression dans le titre</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>General margin</source>
        <translation>Marge générale</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>General spacing</source>
        <translation>Espacement général</translation>
    </message>
    <message>
        <location line="-242"/>
        <source>Always on top</source>
        <translation>Toujours au 1er plan</translation>
    </message>
</context>
</TS>
